%bcond_without     qt5

Summary:        A library having High-Level Crypto API to make access to GnuPG easier
Name:           gpgme
Version:        1.21.0
Release:        7%{?dist}
License:        LGPLv2+ and MIT
URL:            https://gnupg.org/related_software/gpgme/
Source0:        https://gnupg.org/ftp/gcrypt/%{name}/%{name}-%{version}.tar.bz2

Patch0001:      0002-setup_py_extra_opts.patch
Patch3000:      gpgme-1.3.2-largefile.patch
Patch3001:      0001-fix-stupid-ax_python_devel.patch
Patch3002:      1001-qt-skip-test-remarks-for-gnupg2-2.4.patch 
BuildRequires:  make gcc gcc-c++ cmake
BuildRequires:  gawk gnupg2-smime chrpath
BuildRequires:  gnupg2 >= 2.2.24
BuildRequires:  libgpg-error-devel >= 1.36
BuildRequires:  libassuan-devel >= 2.4.2
# For python bindings
BuildRequires:  swig python3-setuptools
Requires:       gnupg2 >= 2.2.24

%description
GnuPG Made Easy (GPGME) is a C language library that allows to add
support for cryptography to a program.  It is designed to make access
to public key crypto engines like GnuPG or GpgSM easier for
applications.  GPGME provides a high-level crypto API for encryption,
decryption, signing, signature verification and key management.

GPGME comes with language bindings for Common Lisp, C++, QT, Python2,
and Python 3.

GPGME uses GnuPG as its backend to support OpenPGP and the
Cryptographic Message Syntax (CMS).


%package devel
Summary:        Development headers and libraries for gpgme
Requires:       %{name} = %{version}-%{release}
Requires:       libgpg-error-devel >= 1.36

%description devel
Development headers and libraries for gpgme.


%package -n %{name}pp
Summary:        C++ bindings/wrapper for gpgme
Requires:       %{name} = %{version}-%{release}
Provides:       gpgme-pp = %{version}-%{release}

%description -n %{name}pp
C++ bindings/wrapper for gpgme.


%package -n %{name}pp-devel
Summary:        Development libraries and header files for %{name}pp
Requires:       %{name}pp = %{version}-%{release}
Requires:       %{name}-devel
Provides:       gpgme-pp-devel = %{version}-%{release}

%description -n %{name}pp-devel
Development libraries and header files for %{name}pp.


%if %{with qt5}
%package -n q%{name}
Summary:        Qt API bindings/wrapper for gpgme
BuildRequires:  pkgconfig(Qt5Core)
BuildRequires:  pkgconfig(Qt5Test)
Requires:       %{name}pp = %{version}-%{release}

%description -n q%{name}
Qt API bindings/wrapper for gpgme.


%package -n q%{name}-devel
Summary:        Development libraries and header files for q%{name}
Requires:       q%{name} = %{version}-%{release}
Requires:       %{name}pp-devel

%description -n q%{name}-devel
Development libraries and header files for q%{name}.
%endif


%package -n python3-gpg
Summary:        Python3 bindings for gpgme
BuildRequires:  python3-devel
Requires:       %{name} = %{version}-%{release}
Obsoletes:      platform-python-gpg < %{version}-%{release}

%description -n python3-gpg
Python3 bindings for gpgme.


%prep
%autosetup -p1


%build
export CFLAGS='%{optflags} -D_LARGEFILE_SOURCE -D_FILE_OFFSET_BITS=64'
export CXXFLAGS='%{optflags} -D_LARGEFILE_SOURCE -D_FILE_OFFSET_BITS=64'

sed -i -e 's|^libdir=@libdir@$|libdir=@exec_prefix@/lib|g' src/gpgme-config.in
sed -i 's/3.8/%{python3_version}/g' configure

%define languages "cpp,python"
%if %{with qt5}
%define languages "cpp,python,qt"
%endif

%configure --disable-static --disable-silent-rules --enable-languages=%{languages}
%make_build


%install
# When using distutils from setuptools 60+, ./setup.py install use the .egg format.
# This forces setuptools to use .egg-info format with Patch0001
export SETUPTOOLS_USE_DISTUTILS=local
export SETUP_PY_EXTRA_OPTS="--single-version-externally-managed --root=/"
%make_install
rm -fv %{buildroot}%{_infodir}/dir
rm -fv %{buildroot}%{_libdir}/lib*.la

chrpath -d %{buildroot}%{_bindir}/%{name}-tool
chrpath -d %{buildroot}%{_bindir}/%{name}-json
chrpath -d %{buildroot}%{_libdir}/lib%{name}pp.so*
%if %{with qt5}
chrpath -d %{buildroot}%{_libdir}/libq%{name}.so*
%endif


%check
make check


%files
%license COPYING* LICENSES
%doc AUTHORS NEWS README*
%{_bindir}/%{name}-json
%{_libdir}/lib%{name}.so.11*


%files devel
%{_bindir}/%{name}-config
%{_bindir}/%{name}-tool
%{_includedir}/%{name}.h
%{_libdir}/lib%{name}.so
%{_libdir}/pkgconfig/%{name}*.pc
%{_datadir}/aclocal/%{name}.m4
%{_infodir}/%{name}.info*


%files -n %{name}pp
%doc lang/cpp/README
%{_libdir}/lib%{name}pp.so.6*


%files -n %{name}pp-devel
%{_includedir}/%{name}++/
%{_libdir}/lib%{name}pp.so
%{_libdir}/cmake/Gpgmepp/


%if %{with qt5}
%files -n q%{name}
%doc lang/qt/README
%{_libdir}/libq%{name}.so.*

%files -n q%{name}-devel
%{_includedir}/q%{name}/
%{_includedir}/QGpgME/
%{_libdir}/libq%{name}.so
%{_libdir}/cmake/QGpgme/
%endif


%files -n python3-gpg
%doc lang/python/README
%{python3_sitearch}/gpg-*.egg-info
%{python3_sitearch}/gpg/


%changelog
* Thu Sep 26 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 1.21.0-7
- Rebuilt for clarifying the packages requirement in BaseOS and AppStream

* Fri Aug 16 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 1.21.0-6
- Rebuilt for loongarch release

* Sat Nov 18 2023 Zhao Zhen <jeremiazhao@tencent.com> - 1.21.0-5
- opened gpgme for qt5 support

* Tue Sep 19 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 1.21.0-4
- Rebuilt for python 3.11

* Fri Sep 08 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 1.21.0-3
- Rebuilt for OpenCloudOS Stream 23.09

* Thu Sep 7 2023 Shuo Wang <abushwang@tencent.com> - 1.21.0-1
- add buildrequires to setuptools for python3.11

* Tue Aug 15 2023 kianli <kianli@tencent.com> - 1.21.0-1
- Upgrade to 1.21.0

* Fri Apr 28 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 1.17.1-4
- Rebuilt for OpenCloudOS Stream 23.05

* Fri Mar 31 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 1.17.1-3
- Rebuilt for OpenCloudOS Stream 23

* Fri Sep 09 2022 rockerzhu <rockerzhu@tencent.com> - 1.17.1-2
- Disable qt5 by default

* Tue Jul 12 2022 rockerzhu <rockerzhu@tencent.com> - 1.17.1-1
- Initial build
